@@ -547,7 +547,7 @@ void InstrView::refresh()
 		      tr("Tip: For Callgrind, rerun with option"));
 	new InstrItem(this, this, 3, tr("      --dump-instr=yes"));
 	new InstrItem(this, this, 4, tr("To see (conditional) jumps, additionally specify"));
-	new InstrItem(this, this, 5, tr("      --trace-jump=yes"));
+	new InstrItem(this, this, 5, tr("      --collect-jumps=yes"));
 	return;
     }
 
