@@ -31,7 +31,7 @@
 #include <QtGui/QRadioButton>
 
 ActivityDialog::ActivityDialog(QWidget * parent, ActivityWidget * pWidget)
-   : KPageDialog(parent)
+   : DialogBase(parent)
 {
     setCaption( i18n("Properties") );
     setButtons( Ok | Apply | Cancel | Help );
@@ -51,7 +51,7 @@ ActivityDialog::ActivityDialog(QWidget * parent, ActivityWidget * pWidget)
  */
 void ActivityDialog::slotOk()
 {
-    applyPage( pageItemColor );
+    applyPage( pageItemStyle );
     applyPage( pageItemFont );
     applyPage( pageItemGeneral );
     accept();
@@ -93,8 +93,8 @@ void ActivityDialog::slotHideActivityParameter()
 void ActivityDialog::setupPages()
 {
     setupGeneralPage();
-    setupColorPage();
-    setupFontPage();
+    pageItemStyle = setupStylePage( m_pActivityWidget );
+    pageItemFont = setupFontPage( m_pActivityWidget );
 }
 
 /**
@@ -120,11 +120,11 @@ void ActivityDialog::applyPage( KPageWidgetItem *item )
     }
     else if ( item == pageItemFont )
     {
-        m_pActivityWidget->setFont( m_pChooser->font() );
+        saveFontPageData( m_pActivityWidget );
     }
-    else if ( item == pageItemColor )
+    else if ( item == pageItemStyle )
     {
-        m_pColorPage->updateUMLWidget();
+        saveStylePageData( m_pActivityWidget );
     }
 }
 
@@ -213,20 +213,6 @@ void ActivityDialog::setupGeneralPage()
         m_GenPageWidgets.nameLE->setText( m_pActivityWidget->name() );
 }
 
-/**
- *   Sets up the font selection page.
- */
-void ActivityDialog::setupFontPage()
-{
-    KVBox *page = new KVBox();
-    pageItemFont = new KPageWidgetItem( page, i18n("Font") );
-    pageItemFont->setHeader( i18n("Font Settings") );
-    pageItemFont->setIcon( Icon_Utils::DesktopIcon(Icon_Utils::it_Properties_Font) );
-    addPage( pageItemFont );
-    m_pChooser = new KFontChooser( (QWidget*)page, KFontChooser::NoDisplayFlags, QStringList(), 0);
-    m_pChooser->setFont( m_pActivityWidget->font() );
-}
-
 /**
  *   Show the Activity Parameter entry text.
  */
@@ -244,19 +230,4 @@ void ActivityDialog::showParameterActivity()
     }
 }
 
-/**
- *   Sets up the color page.
- */
-void ActivityDialog::setupColorPage()
-{
-    QFrame *colorPage = new QFrame();
-    pageItemColor = new KPageWidgetItem( colorPage, i18nc("widget color page", "Color") );
-    pageItemColor->setHeader( i18n("Widget Colors") );
-    pageItemColor->setIcon( Icon_Utils::DesktopIcon(Icon_Utils::it_Properties_Color) );
-    addPage( pageItemColor );
-    QHBoxLayout * m_pColorLayout = new QHBoxLayout(colorPage);
-    m_pColorPage = new UMLWidgetColorPage( colorPage, m_pActivityWidget );
-    m_pColorLayout->addWidget(m_pColorPage);
-}
-
 #include "activitydialog.moc"
