@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2011                                               *
+ *   copyright (C) 2002-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -34,7 +34,7 @@
 #include <QtGui/QRadioButton>
 
 ObjectNodeDialog::ObjectNodeDialog( UMLView * pView, ObjectNodeWidget * pWidget )
-        : KPageDialog(pView)
+  : DialogBase(pView)
 {
     setCaption( i18n("Properties") );
     setButtons( Ok | Apply | Cancel | Help );
@@ -55,7 +55,7 @@ ObjectNodeDialog::ObjectNodeDialog( UMLView * pView, ObjectNodeWidget * pWidget
  */
 void ObjectNodeDialog::slotOk()
 {
-    applyPage( pageItemColor );
+    applyPage( pageItemStyle );
     applyPage( pageItemFont );
     applyPage( pageItemGeneral );
     accept();
@@ -91,8 +91,8 @@ void ObjectNodeDialog::slotHideState()
 void ObjectNodeDialog::setupPages()
 {
     setupGeneralPage();
-    setupColorPage();
-    setupFontPage();
+    pageItemStyle = setupStylePage( m_pObjectNodeWidget ) ;
+    pageItemFont = setupFontPage( m_pObjectNodeWidget );
 }
 
 /**
@@ -119,11 +119,11 @@ void ObjectNodeDialog::applyPage( KPageWidgetItem *item )
     }
     else if ( item == pageItemFont )
     {
-        m_pObjectNodeWidget->setFont( m_pChooser->font() );
+        saveFontPageData( m_pObjectNodeWidget );
     }
-    else if ( item == pageItemColor )
+    else if ( item == pageItemStyle )
     {
-        m_pColorPage->updateUMLWidget();
+        saveStylePageData( m_pObjectNodeWidget );
     }
 }
 
@@ -211,20 +211,6 @@ void ObjectNodeDialog::setupGeneralPage()
         m_GenPageWidgets.nameLE->setText( m_pObjectNodeWidget->name() );
 }
 
-/**
- * Sets up the font selection page.
- */
-void ObjectNodeDialog::setupFontPage()
-{
-    KVBox *page = new KVBox();
-    pageItemFont = new KPageWidgetItem( page, i18n("Font") );
-    pageItemFont->setHeader( i18n("Font Settings") );
-    pageItemFont->setIcon( Icon_Utils::DesktopIcon(Icon_Utils::it_Properties_Font) );
-    addPage( pageItemFont );
-    m_pChooser = new KFontChooser( (QWidget*)page, KFontChooser::NoDisplayFlags, QStringList(), 0);
-    m_pChooser->setFont( m_pObjectNodeWidget->font() );
-}
-
 /**
  * Show the State entry text.
  */
@@ -238,19 +224,4 @@ void ObjectNodeDialog::showState()
     }
 }
 
-/**
- * Sets up the color page.
- */
-void ObjectNodeDialog::setupColorPage()
-{
-    QFrame *colorPage = new QFrame();
-    pageItemColor = new KPageWidgetItem( colorPage, i18nc("color page title", "Color") );
-    pageItemColor->setHeader( i18n("Widget Colors") );
-    pageItemColor->setIcon( Icon_Utils::DesktopIcon(Icon_Utils::it_Properties_Color) );
-    addPage( pageItemColor );
-    QHBoxLayout * m_pColorLayout = new QHBoxLayout(colorPage);
-    m_pColorPage = new UMLWidgetColorPage( colorPage, m_pObjectNodeWidget );
-    m_pColorLayout->addWidget(m_pColorPage);
-}
-
 #include "objectnodedialog.moc"
